==> jc-1.4.0.tar.gz: polyglot/util/CollectionUtil.h <==
// public class polyglot.util.CollectionUtil

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 32f10c9680c602c0 polyglot_util_CollectionUtil

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_CollectionUtil_H_
#define _JC_polyglot_util_CollectionUtil_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_util_Transformation$object;

// Typedefs
typedef struct _jc_polyglot_util_CollectionUtil$sub_refs	_jc_polyglot_util_CollectionUtil$sub_refs;
typedef struct _jc_polyglot_util_CollectionUtil$sub_nonrefs	_jc_polyglot_util_CollectionUtil$sub_nonrefs;
typedef struct _jc_polyglot_util_CollectionUtil$refs	_jc_polyglot_util_CollectionUtil$refs;
typedef struct _jc_polyglot_util_CollectionUtil$nonrefs	_jc_polyglot_util_CollectionUtil$nonrefs;
typedef struct _jc_polyglot_util_CollectionUtil$object	_jc_polyglot_util_CollectionUtil$object;

typedef const struct _jc_polyglot_util_CollectionUtil$vmethods	_jc_polyglot_util_CollectionUtil$vmethods;
typedef const struct _jc_polyglot_util_CollectionUtil$vtable	_jc_polyglot_util_CollectionUtil$vtable;
typedef const struct _jc_polyglot_util_CollectionUtil$vtype	_jc_polyglot_util_CollectionUtil$vtype;

// Constructors
extern void _jc_polyglot_util_CollectionUtil$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_CollectionUtil$object *);

// Static methods
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$add$ea34dece78dbde5c(_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_polyglot_util_CollectionUtil$method$equals$948f6f4044528402(_jc_env *, struct _jc_object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_CollectionUtil$method$firstOrElse$09792db844aa8527(_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$list$3206d8690b3dcbcc(_jc_env *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$list$424c62718e83e503(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$list$1d9b99e03711ed53(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$list$7f3b775a0524118d(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$map$40dc590db0fd1172(_jc_env *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$pairs$dfe4b5dbc839dfa1(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_polyglot_util_CollectionUtil$vmethods {
};

// Vtable
struct _jc_polyglot_util_CollectionUtil$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_CollectionUtil$vmethods	polyglot_util_CollectionUtil;
};

// Vtype
struct _jc_polyglot_util_CollectionUtil$vtype {
	_jc_type			type;
	_jc_polyglot_util_CollectionUtil$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_CollectionUtil$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_CollectionUtil$refs {
    _jc_polyglot_util_CollectionUtil$sub_refs	polyglot_util_CollectionUtil;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_CollectionUtil$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_CollectionUtil$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_CollectionUtil$sub_nonrefs	polyglot_util_CollectionUtil;
};

// Object instance structure
struct _jc_polyglot_util_CollectionUtil$object {
	_jc_polyglot_util_CollectionUtil$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_CollectionUtil$vtype	*vtype;
	_jc_polyglot_util_CollectionUtil$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_CollectionUtil$vtype _jc_polyglot_util_CollectionUtil$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_CollectionUtil, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_CollectionUtil$class_object;

#endif	/* _JC_polyglot_util_CollectionUtil_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/CollectionUtil.h <==
// public class polyglot.util.CollectionUtil

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 32f10c9680c602c0 polyglot_util_CollectionUtil

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_CollectionUtil_H_
#define _JC_polyglot_util_CollectionUtil_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_util_Transformation$object;

// Typedefs
typedef struct _jc_polyglot_util_CollectionUtil$sub_refs	_jc_polyglot_util_CollectionUtil$sub_refs;
typedef struct _jc_polyglot_util_CollectionUtil$sub_nonrefs	_jc_polyglot_util_CollectionUtil$sub_nonrefs;
typedef struct _jc_polyglot_util_CollectionUtil$refs	_jc_polyglot_util_CollectionUtil$refs;
typedef struct _jc_polyglot_util_CollectionUtil$nonrefs	_jc_polyglot_util_CollectionUtil$nonrefs;
typedef struct _jc_polyglot_util_CollectionUtil$object	_jc_polyglot_util_CollectionUtil$object;

typedef const struct _jc_polyglot_util_CollectionUtil$vmethods	_jc_polyglot_util_CollectionUtil$vmethods;
typedef const struct _jc_polyglot_util_CollectionUtil$vtable	_jc_polyglot_util_CollectionUtil$vtable;
typedef const struct _jc_polyglot_util_CollectionUtil$vtype	_jc_polyglot_util_CollectionUtil$vtype;

// Constructors
extern void _jc_polyglot_util_CollectionUtil$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_CollectionUtil$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$add$ea34dece78dbde5c(_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_util_CollectionUtil$method$equals$948f6f4044528402(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_CollectionUtil$method$firstOrElse$09792db844aa8527(_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$list$3206d8690b3dcbcc(_jc_env *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$list$424c62718e83e503(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$list$1d9b99e03711ed53(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$list$7f3b775a0524118d(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$map$40dc590db0fd1172(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_util_CollectionUtil$method$pairs$dfe4b5dbc839dfa1(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_CollectionUtil$vmethods {
};

// Vtable
struct _jc_polyglot_util_CollectionUtil$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_CollectionUtil$vmethods	polyglot_util_CollectionUtil;
};

// Vtype
struct _jc_polyglot_util_CollectionUtil$vtype {
	_jc_type			type;
	_jc_polyglot_util_CollectionUtil$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_CollectionUtil$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_CollectionUtil$refs {
    _jc_polyglot_util_CollectionUtil$sub_refs	polyglot_util_CollectionUtil;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_CollectionUtil$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_CollectionUtil$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_CollectionUtil$sub_nonrefs	polyglot_util_CollectionUtil;
};

// Object instance structure
struct _jc_polyglot_util_CollectionUtil$object {
	_jc_polyglot_util_CollectionUtil$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_CollectionUtil$vtype	*vtype;
	_jc_polyglot_util_CollectionUtil$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_CollectionUtil$vtype _jc_polyglot_util_CollectionUtil$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_CollectionUtil, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_CollectionUtil$class_object;

#endif	/* _JC_polyglot_util_CollectionUtil_H_ */
